@@ -6,9 +6,10 @@ from boltons.strutils import slugify
 from click import ClickException
 
 from yappa.config_generation import create_default_gw_config, inject_function_id
-from yappa.handlers.wsgi import load_yaml, save_yaml
+
 from yappa.s3 import prepare_package, upload_to_bucket
-from yappa.utils import HANDLERS, get_yc_entrypoint
+from yappa.utils import get_yc_entrypoint, load_yaml, save_yaml
+from yappa.settings import HANDLERS
 
 
 class NaturalOrderGroup(click.Group):
