@@ -8,18 +8,25 @@ DEFAULT_REQUIREMENTS_FILE = "requirements.txt"
 DEFAULT_ACCESS_KEY_FILE = ".yc"
 DEFAULT_SERVICE_ACCOUNT = "yappa-uploader-service"
 DEFAULT_IGNORED_FILES = (
-    ".idea",
-    ".git",
-    "venv",
-    "requirements.txt",
-)
+        ".idea",
+        ".git",
+        "venv",
+        "requirements.txt",
+        )
 AVAILABLE_PYTHON_VERSIONS = (
-    "python38",
-    "python37",
-)
+        "python38",
+        "python37",
+        )
 YANDEX_S3_URL = 'https://storage.yandexcloud.net'
 YANDEX_CLIENT_ID = "9878e3bd8f1e4bc292ee9c74bbc736a2"
 YANDEX_OAUTH_URL = furl("https://oauth.yandex.ru/authorize").add({
-    "response_type": "token",
-    "client_id": YANDEX_CLIENT_ID,
-}).url
+        "response_type": "token",
+        "client_id": YANDEX_CLIENT_ID,
+        }).url
+HANDLERS = {
+        "wsgi": "handlers.wsgi.handle",
+        "django": "handlers.wsgi.handle",
+        "asgi": "handlers.asgi.handle",
+        "raw": None,
+        }
+DEFAULT_CONFIG_FILENAME = "yappa.yaml"
\ No newline at end of file
